@@ -1,4 +1,4 @@
-/* $Id: gucharmap-charmap.c,v 1.32 2003/08/01 14:41:22 nlevitt Exp $ */
+/* $Id: gucharmap-charmap.c,v 1.35 2003/11/18 19:54:59 mariano Exp $ */
 /*
  * Copyright (c) 2003  Noah Levitt <nlevitt аt users.sourceforge.net>
  *
@@ -201,6 +201,17 @@ make_unicode_block_selector (GucharmapCharmap *charmap)
 }
 
 
+static void 
+charmap_finalize (GObject *object)
+{
+  GucharmapCharmap *charmap = GUCHARMAP_CHARMAP (object);
+  g_free (charmap->block_index);
+
+  gdk_cursor_unref (charmap->hand_cursor);
+  gdk_cursor_unref (charmap->regular_cursor);
+}
+
+
 void
 gucharmap_charmap_class_init (GucharmapCharmapClass *clazz)
 {
@@ -219,6 +230,8 @@ gucharmap_charmap_class_init (GucharmapCharmapClass *clazz)
                     G_STRUCT_OFFSET (GucharmapCharmapClass, link_clicked),
                     NULL, NULL, gucharmap_marshal_VOID__UINT_UINT, G_TYPE_NONE, 
 		    2, G_TYPE_UINT, G_TYPE_UINT);
+
+  G_OBJECT_CLASS (clazz)->finalize = charmap_finalize;
 }
 
 
@@ -429,21 +442,15 @@ set_details (GucharmapCharmap *charmap,
 
   gtk_text_buffer_get_start_iter (buffer, &iter);
   gtk_text_buffer_place_cursor (buffer, &iter);
-  gtk_text_buffer_insert (buffer, &iter, "\n\n", -1);
+  gtk_text_buffer_insert (buffer, &iter, "\n", -1);
 
   n = gucharmap_unichar_to_printable_utf8 (uc, buf);
   if (n == 0)
     gtk_text_buffer_insert_with_tags_by_name (
             buffer, &iter, _("[not a printable character]"), -1, NULL);
   else
-    {
-      /* give it some space to breathe */
-      /* gtk_text_buffer_insert (buffer, &iter, "     ", -1); */
-      gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, "   ", -1, 
-                                                "gimongous", NULL);
-      gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, buf, n, 
-                                                "gimongous", NULL);
-    }
+    gtk_text_buffer_insert_with_tags_by_name (buffer, &iter, buf, n, 
+                                              "gimongous", NULL);
 
   gtk_text_buffer_insert (buffer, &iter, "\n\n", -1);
                                              
@@ -646,6 +653,7 @@ create_tags (GucharmapCharmap *charmap)
 
   gtk_text_buffer_create_tag (buffer, "gimongous", 
 	                      "size", 8 * default_font_size, 
+                              "left-margin", PANGO_PIXELS (5 * default_font_size),
 			      NULL);
   gtk_text_buffer_create_tag (buffer, "bold",
 	                      "weight", PANGO_WEIGHT_BOLD,
