@@ -1,4 +1,4 @@
-/* $Id: gucharmap-mini-fontsel.c,v 1.5 2003/09/04 22:39:16 nlevitt Exp $ */
+/* $Id: gucharmap-mini-fontsel.c,v 1.6 2003/10/02 21:20:54 nlevitt Exp $ */
 /*
  * Copyright (c) 2003 Noah Levitt
  *
@@ -142,8 +142,9 @@ size_changed (GtkAdjustment *adjustment,
 
 
 static void
-mini_font_selection_finalize (GucharmapMiniFontSelection *fontsel)
+mini_font_selection_finalize (GObject *object)
 {
+  GucharmapMiniFontSelection *fontsel = GUCHARMAP_MINI_FONT_SELECTION (object);
   pango_font_description_free (fontsel->font_desc);
 }
 
