@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: generator.sh,v 1.3 2003/03/28 20:37:11 cneumair Exp $
+# $Id: generator.sh,v 1.4 2003/05/04 22:13:53 nlevitt Exp $
 # 
 
 #
@@ -101,7 +101,7 @@ write_blocks()
     $ECHO "/* THIS IS A GENERATED FILE. */"
     $ECHO "/* http://www.unicode.org/Public/UNIDATA/Blocks.txt */"
     $ECHO "" 
-    $ECHO "const UnicodeBlock unicode_blocks[] ="
+    $ECHO "const GucharmapUnicodeBlock gucharmap_unicode_blocks[] ="
     $ECHO "{"
 
     while read line
